@@ -30,13 +30,12 @@
 #include <libgnome/gnome-desktop-item.h>
 #include <libgnomeui/gnome-help.h>
 #include <libgnomeui/gnome-window-icon.h>
-#include <menu-tree.h>
+#include <gmenu-tree.h>
 #include "dlg-pick-applications.h"
 #include "dlg-properties.h"
 #include "gtk-utils.h"
 #include "file-utils.h"
 
-
 #define GLADE_FILE      "quick-lounge.glade"
 #define ICON_SIZE_MENU  22    /* icons size in menus */
 
@@ -103,7 +102,7 @@ help_cb (GtkWidget  *widget,
 						 GTK_BUTTONS_CLOSE,
 						 _("Could not display help: %s"),
 						 err->message);
-		gnome_window_icon_set_from_file (GTK_WINDOW (dialog), GNOME_ICONDIR "quick-lounge-applet.png");
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), "quick-lounge-applet");
 		gtk_window_set_screen (GTK_WINDOW (dialog), gtk_widget_get_screen (GTK_WIDGET (data->quick_lounge->applet)));	
 	
 		g_signal_connect (G_OBJECT (dialog), "response",
@@ -177,67 +176,67 @@ ok_cb (GtkWidget  *widget,
 void
 add_applications_from_dir (DialogData         *data,
 			   GtkTreeIter        *tree_iter,
-			   MenuTreeDirectory  *menu_dir)
+			   GMenuTreeDirectory  *menu_dir)
 {
 	QuickLounge *quick_lounge = data->quick_lounge;
-	GSList      *entries, *subdirs, *scan;
+	GSList      *items, *scan;
+
 	GtkTreeIter  iter;
 
-	subdirs = menu_tree_directory_get_subdirs (menu_dir);
-	for (scan = subdirs; scan; scan = scan->next) {
-		MenuTreeDirectory *dir = scan->data;
+	items = gmenu_tree_directory_get_contents (menu_dir);
+
+	for (scan = items; scan; scan = scan->next) {
+		GMenuTreeItem *item = scan->data;
 		const char        *icon_path = NULL;
 		GdkPixbuf         *icon = NULL;
 
-		icon_path = menu_tree_directory_get_icon (dir);
-		if (icon_path != NULL) 
-			icon = create_pixbuf (quick_lounge->icon_theme, icon_path, ICON_SIZE_MENU);
-
-		gtk_tree_store_append (GTK_TREE_STORE (data->model), &iter, tree_iter);
-		gtk_tree_store_set (GTK_TREE_STORE (data->model), &iter,
+		switch (gmenu_tree_item_get_type (item)) {
+		case GMENU_TREE_ITEM_DIRECTORY:
+			icon_path = gmenu_tree_entry_get_icon (GMENU_TREE_ENTRY (item));
+			if (icon_path != NULL)
+				icon = create_pixbuf (quick_lounge->icon_theme, icon_path, ICON_SIZE_MENU);
+		
+			gtk_tree_store_append (GTK_TREE_STORE (data->model), &iter, tree_iter);
+			gtk_tree_store_set (GTK_TREE_STORE (data->model), &iter,
 				    APP_URI_COLUMN, NULL,
 				    USE_APP_COLUMN, FALSE,
 				    IS_LAUNCHER_COLUMN, FALSE,
 				    APP_ICON_COLUMN, icon,
-				    APP_NAME_COLUMN, menu_tree_directory_get_name (dir),
-				    APP_COMMENT_COLUMN, menu_tree_directory_get_comment (dir),
+				    APP_NAME_COLUMN, gmenu_tree_entry_get_name (GMENU_TREE_ENTRY (item)),
+				    APP_COMMENT_COLUMN, gmenu_tree_entry_get_comment (GMENU_TREE_ENTRY (item)),
 				    -1);
+			if (icon != NULL)
+				g_object_unref (icon);
 
-		if (icon != NULL)
-			g_object_unref (icon);
-
-		add_applications_from_dir (data, &iter, dir);
-
-		menu_tree_directory_unref (dir);
-	}
-	g_slist_free (subdirs);
-
-	entries = menu_tree_directory_get_entries (menu_dir);
-	for (scan = entries; scan; scan = scan->next) {
-		MenuTreeEntry *entry = scan->data;
-		const char    *icon_path = NULL;
-		GdkPixbuf     *icon = NULL;
-
-		icon_path = menu_tree_entry_get_icon (entry);
-		if (icon_path != NULL)
-			icon = create_pixbuf (quick_lounge->icon_theme, icon_path, ICON_SIZE_MENU);
-
-		gtk_tree_store_append (GTK_TREE_STORE (data->model), &iter, tree_iter);
-		gtk_tree_store_set (GTK_TREE_STORE (data->model), &iter,
-				    APP_URI_COLUMN, menu_tree_entry_get_desktop_file_path (entry),
+			add_applications_from_dir (data, &iter, GMENU_TREE_DIRECTORY (item));
+			break;
+		case GMENU_TREE_ITEM_ENTRY:
+			icon_path = gmenu_tree_entry_get_icon (GMENU_TREE_ENTRY (item));
+			if (icon_path != NULL)
+				icon = create_pixbuf (quick_lounge->icon_theme, icon_path, ICON_SIZE_MENU);
+		
+			gtk_tree_store_append (GTK_TREE_STORE (data->model), &iter, tree_iter);
+			gtk_tree_store_set (GTK_TREE_STORE (data->model), &iter,
+				    APP_URI_COLUMN, gmenu_tree_entry_get_desktop_file_path (GMENU_TREE_ENTRY (item)),
 				    USE_APP_COLUMN, FALSE,
 				    IS_LAUNCHER_COLUMN, TRUE,
 				    APP_ICON_COLUMN, icon,
-				    APP_NAME_COLUMN, menu_tree_entry_get_name (entry),
-				    APP_COMMENT_COLUMN, menu_tree_entry_get_comment (entry),
+				    APP_NAME_COLUMN, gmenu_tree_entry_get_name (GMENU_TREE_ENTRY (item)),
+				    APP_COMMENT_COLUMN, gmenu_tree_entry_get_comment (GMENU_TREE_ENTRY (item)),
 				    -1);
+		
+			if (icon != NULL)
+				g_object_unref (icon);
 
-		if (icon != NULL)
-			g_object_unref (icon);
+			break;
+		default:
+			break;
+		}
 
-		menu_tree_entry_unref (entry);
+		gmenu_tree_item_unref (item);
 	}
-	g_slist_free (entries);
+
+	g_slist_free (items);
 }
 
 
@@ -245,20 +244,20 @@ void
 add_applications (DialogData  *data,
 		  const char  *menu_file)
 {
-	MenuTree           *menu_tree;
-	MenuTreeDirectory  *menu_dir;
+	GMenuTree           *menu_tree;
+	GMenuTreeDirectory  *menu_dir;
 
-	menu_tree = menu_tree_lookup (menu_file);
+	menu_tree = gmenu_tree_lookup (menu_file, GMENU_TREE_FLAGS_NONE);
 	if (menu_tree == NULL)
 		return;
 
-	menu_dir = menu_tree_get_root_directory (menu_tree);
+	menu_dir = gmenu_tree_get_root_directory (menu_tree);
 	add_applications_from_dir (data, NULL, menu_dir);
-	menu_tree_directory_unref (menu_dir);
+	gmenu_tree_item_unref (menu_dir);
 
 	gtk_tree_view_expand_all (GTK_TREE_VIEW (data->tree_view));
 
-	menu_tree_unref (menu_tree);
+	gmenu_tree_unref (menu_tree);
 }
 
 
@@ -488,6 +487,9 @@ dlg_pick_applications (QuickLounge  *quick_lounge,
 
 	g_object_set_data (G_OBJECT (data->dialog), "dialog_data", data);
 
+        gtk_window_set_screen (GTK_WINDOW (data->dialog),
+                               gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+	
 	gtk_widget_show (data->dialog);
 
 	add_applications (data, "applications.menu"); 
