@@ -79,7 +79,7 @@ struct _QuickBoxPrivate {
 	PopulateMenuFunc   populate_menu_func;
 	gpointer           populate_menu_data;
 
-	GnomeIconTheme    *icon_theme;
+	GtkIconTheme      *icon_theme;
 };
 
 
@@ -1270,6 +1270,9 @@ display_popup_menu (QuickBox *quick_box)
 				  G_CALLBACK (deactivate_arrow), 
 				  quick_box);
 
+        gtk_menu_set_screen (GTK_MENU (popup_menu),
+                             gtk_widget_get_screen (GTK_WIDGET (quick_box)));
+
 	gtk_menu_popup (GTK_MENU (popup_menu),
 			NULL, NULL, 
 			popup_menu_position, 
@@ -1313,6 +1316,18 @@ deactivate_arrow (QuickBox *quick_box)
 }
 
 
+static gboolean
+arrow_button_do_not_eat_button_press (GtkWidget	*widget,
+				      GdkEventButton *event)
+{
+	if (event->button != 1) {
+		g_signal_stop_emission_by_name (widget, "button_press_event");
+	}
+
+	return FALSE;
+}
+
+
 static GtkWidget *
 create_arrow_button (QuickBox     *quick_box,
 		     GtkArrowType  arrow_type)
@@ -1332,7 +1347,10 @@ create_arrow_button (QuickBox     *quick_box,
 			      button,
 			      _("Show hidden launchers"),
 			      NULL);
-
+	g_signal_connect (G_OBJECT (button), 
+			  "button_press_event",
+			  G_CALLBACK (arrow_button_do_not_eat_button_press), 
+			  NULL);
 	g_signal_connect (G_OBJECT (button), 
 			  "toggled",
 			  G_CALLBACK (arrow_button_toggled), 
@@ -1537,7 +1555,7 @@ button_drag_started_cb (GtkWidget *button,
 
 
 static void
-icon_theme_changed (GnomeIconTheme *icon_theme,
+icon_theme_changed (GtkIconTheme  *icon_theme,
 		    QuickBox       *quick_box)
 {
 	GList *children, *scan;
@@ -1672,7 +1690,7 @@ quick_box_add_separator (QuickBox *quick_box,
 GtkWidget*     
 quick_box_new (PanelAppletOrient  orient,
 	       int                size,
-	       GnomeIconTheme    *icon_theme)
+	       GtkIconTheme      *icon_theme)
 {
 	QuickBox *quick_box;
 
